@@ -281,15 +281,15 @@ impl CommandManager {
                 Ok(None)
             }
             Command::AddCurrent => {
-                if let Some(track) = self.queue.get_current() {
-                    if let Some(track) = track.track() {
-                        let dialog = ContextMenu::add_track_dialog(
-                            self.library.clone(),
-                            self.queue.get_spotify(),
-                            track,
-                        );
-                        s.add_layer(dialog);
-                    }
+                if let Some(track) = self.queue.get_current()
+                    && let Some(track) = track.track()
+                {
+                    let dialog = ContextMenu::add_track_dialog(
+                        self.library.clone(),
+                        self.queue.get_spotify(),
+                        track,
+                    );
+                    s.add_layer(dialog);
                 }
                 Ok(None)
             }
