@@ -226,12 +226,12 @@ impl View for StatusBar {
                     self.spotify.seek_relative(500);
                 }
 
-                if event == MouseEvent::Press(MouseButton::Left) {
-                    if let Some(playable) = self.queue.get_current() {
-                        let f: f32 = position.x as f32 / self.last_size.x as f32;
-                        let new = playable.duration() as f32 * f;
-                        self.spotify.seek(new as u32);
-                    }
+                if event == MouseEvent::Press(MouseButton::Left)
+                    && let Some(playable) = self.queue.get_current()
+                {
+                    let f: f32 = position.x as f32 / self.last_size.x as f32;
+                    let new = playable.duration() as f32 * f;
+                    self.spotify.seek(new as u32);
                 }
             } else if self.last_size.x - position.x < volume_len {
                 if event == MouseEvent::WheelUp {
